@@ -5,6 +5,7 @@ http://smstools3.kekekasvi.com/
 
 Based on SMS Server Tools 2 from Stefan Frings
 http://www.meinemullemaus.de/
+SMS Server Tools version 2 and below are Copyright (C) Stefan Frings.
 
 This program is free software unless you got it under another license directly
 from the author. You can redistribute it and/or modify it under the terms of
@@ -17,6 +18,16 @@ Either version 2 of the License, or (at your option) any later version.
 
 #include <stdio.h>
 
+/* Converts a string to a boolean value. The string can be:
+   1=  true, yes, on, 1
+   0 = all other strings
+   Only the first character is significant. */
+		
+int yesno(char *value);
+
+/* Like yesno, but defaults to -1. 0 = false, no, off, 0 */
+int yesno_check(char *value);
+
 /* removes all ctrl chars */
 char *cut_ctrl(char* message);
 
@@ -29,15 +40,15 @@ int movefile(char* filename, char* directory);
 
 /* Moves a file into another directory. Destination file is protected with
    a lock file during the operation. Returns 1 if success. */
-int movefilewithdestlock(char* filename, char* directory);
+//int movefilewithdestlock(char* filename, char* directory);
 int movefilewithdestlock_new(char* filename, char* directory, int keep_fname, int store_original_fname, char *prefix, char *newfilename);
 
 /* removes ctrl chars at the beginning and the end of the text and removes */
-/* \r in the text. */
-void cutspaces(char* text);
+/* \r in the text. Returns text.*/
+char *cutspaces(char *text);
 
 /* removes all empty lines */
-void cut_emptylines(char* text);
+char *cut_emptylines(char *text);
 
 /* Checks if the text contains only numbers. */
 int is_number(char* text);
