@@ -1,6 +1,6 @@
 /*
 SMS Server Tools 3
-Copyright (C) 2006- Keijo Kasvi
+Copyright (C) Keijo Kasvi
 http://smstools3.kekekasvi.com/
 
 Based on SMS Server Tools 2 from Stefan Frings
@@ -48,7 +48,7 @@ int add_warning(char *buffer, char *format, ...)
     else
     {
       result = 0;
-      writelogfile(LOG_ERR, 1, "PDU %s%s", title, text);
+      writelogfile(LOG_ERR, process_title, "PDU %s%s", title, text);
     }
   }
 
@@ -169,7 +169,7 @@ int text2pdu(char* text, int length, char* pdu, char* udh)
   if (length>maxsms_pdu-udh_size_septets)
     length=maxsms_pdu-udh_size_septets;
   //clear the tmp buffer
-  for (character=0;(size_t)character<sizeof(tmp);character++)
+  for (character=0;character<sizeof(tmp);character++)
     tmp[character]=0;
   // Convert 8bit text stream to 7bit stream
   for (character=0;character<length;character++)
@@ -215,75 +215,6 @@ void binary2pdu(char* binary, int length, char* pdu)
   }
 }
 
-int set_numberformat(int *numberformat, char *number, int number_type)
-{
-  int nf = NF_INTERNATIONAL;
-  char *p;
-
-  if (numberformat)
-    nf = *numberformat;
-
-  if (nf == NF_INTERNATIONAL)
-  {
-    // If international prefixes are defined, international format is used if a number matches to the list.
-    // If it does not match, national format will be used.
-    if (*international_prefixes)
-    {
-      p = international_prefixes;
-      do
-      {
-        if (!strncmp(number, p, strlen(p)))
-          break;
-        p += strlen(p) +1;
-      }
-      while (*p);
-
-      if (!(*p))
-        nf = NF_NATIONAL;
-    }
-    
-    if (nf == NF_INTERNATIONAL)
-    {
-      // If national prefixes are defined, national format is used if a number matches to the list.
-      if (*national_prefixes)
-      {
-        p = national_prefixes;
-        do
-        {
-          if (!strncmp(number, p, strlen(p)))
-          {
-            nf = NF_NATIONAL;
-            break;
-          }
-          p += strlen(p) +1;
-        }
-        while (*p);
-      }
-    }
-  }
-
-  // Finally, user setting overrides all...
-  switch (number_type)
-  {
-    case 0: // "unknown"
-      nf = NF_UNKNOWN; // 1000 0001
-      break;
-
-    case 1: // "international"
-      nf = NF_INTERNATIONAL; // 1001 0001
-      break;
-
-    case 2: // "national"
-      nf = NF_NATIONAL; // 1010 0001
-      break;
-  }
-
-  if (numberformat)
-    *numberformat = nf;
-
-  return nf;
-}
-
 // Make the PDU string from a mesage text and destination phone number.
 // The destination variable pdu has to be big enough. 
 // alphabet indicates the character set of the message.
@@ -292,7 +223,7 @@ int set_numberformat(int *numberformat, char *number, int number_type)
 // if udh is true, then udh_data contains the optional user data header in hex dump, example: "05 00 03 AF 02 01"
 
 void make_pdu(char* number, char* message, int messagelen, int alphabet, int flash_sms, int report, int with_udh,
-              char* udh_data, char* mode, char* pdu, int validity, int replace_msg, int system_msg, int number_type)
+              char* udh_data, char* mode, char* pdu, int validity, int replace_msg, int system_msg)
 {
   int coding;
   int flags;
@@ -303,19 +234,16 @@ void make_pdu(char* number, char* message, int messagelen, int alphabet, int fla
   char *p;
   int l;
 
-  if (number[0] == 's')  // Is number starts with s, then send it without number format indicator
+  if (number[0]=='s')  // Is number starts with s, then send it without number format indicator
   {
-    numberformat = NF_UNKNOWN;
-    strcpy(tmp, number +1);
+    numberformat=129; // 1000 0001
+    strcpy(tmp,number+1);
   }
   else
   {
-    numberformat = NF_INTERNATIONAL;
-    strcpy(tmp, number);
+    numberformat=145; // 1001 0001
+    strcpy(tmp,number);
   }
-
-  set_numberformat(&numberformat, tmp, number_type);
-
   numberlength=strlen(tmp);
   // terminate the number with F if the length is odd
   if (numberlength%2)
@@ -350,7 +278,7 @@ void make_pdu(char* number, char* message, int messagelen, int alphabet, int fla
     {
       strcpy(tmp2, udh_data);
       while ((p = strchr(tmp2, ' ')))
-        memmove(p, p +1, strlen(p +1) +1);
+        strcpy(p, p +1);
       l = strlen(tmp2) /2;
       binary2pdu(message, messagelen, strchr(tmp2, 0));
       messagelen += l;
@@ -360,38 +288,18 @@ void make_pdu(char* number, char* message, int messagelen, int alphabet, int fla
   }
   else
     messagelen=text2pdu(message,messagelen,tmp2,udh_data);
-
   /* concatenate the first part of the PDU string */
   if (strcmp(mode,"old")==0)
     sprintf(pdu,"%02X00%02X%02X%s00%02X%02X",flags,numberlength,numberformat,tmp,coding,messagelen);
   else
   {
-    int proto = 0;
-
     if (validity < 0 || validity > 255)
       validity = validity_period;
-
-    if (system_msg)
-    {
-      proto = 0x40;
-      coding = 0xF4;  // binary
-
-      // 3.1.7:
-      if (system_msg == 2)
-      {
-        proto += (0x7F - 0x40); // SS (no show)
-        coding += 2;    // store to sim
-      }
-    }
-    else if (replace_msg >= 1 && replace_msg <= 7)
-       proto = 0x40 + replace_msg;
-
-    //sprintf(pdu, "00%02X00%02X%02X%s%02X%02X%02X%02X", flags, numberlength, numberformat, tmp,
-    // (system_msg) ? 0x40 : (replace_msg >= 1 && replace_msg <= 7) ? 0x40 + replace_msg : 0,
-    // (system_msg) ? 0xF4 : coding, validity, messagelen);
-    sprintf(pdu, "00%02X00%02X%02X%s%02X%02X%02X%02X", flags, numberlength, numberformat, tmp, proto, coding, validity, messagelen);
+    sprintf(pdu, "00%02X00%02X%02X%s%02X%02X%02X%02X",
+            flags, numberlength, numberformat, tmp,
+            (system_msg)? 0x40 : (replace_msg >= 1 && replace_msg <= 7)? 0x40 +replace_msg : 0,
+            (system_msg)? 0xF4 : coding, validity, messagelen);
   }
-
   /* concatenate the text to the PDU string */
   strcat(pdu,tmp2);
 }
@@ -550,12 +458,12 @@ int explain_udh(char *udh_type, char *pdu)
     return -1;
   strcpy(buffer, pdu);
   while ((p = strchr(buffer, ' ')))
-    memmove(p, p +1, strlen(p +1) +1);
+    strcpy(p, p +1);
 
   if ((udh_length = octet2bin_check(buffer)) < 0)
     return -1;
   udh_length++;
-  if ((size_t)(udh_length *2) > strlen(buffer))
+  if (udh_length *2 > strlen(buffer))
     return -1;
   sprintf(udh_type, "Length=%i", udh_length);
   idx = 1;
@@ -632,7 +540,7 @@ int explain_udh(char *udh_type, char *pdu)
     // Next octet is length of data:
     if ((i = octet2bin_check(Src_Pointer +2)) < 0)
       return -1;
-    if ((size_t)(i *2) > strlen(Src_Pointer +4))
+    if (i *2 > strlen(Src_Pointer +4))
       return -1;
     idx += i +2;
     if (idx > udh_length)
@@ -661,7 +569,7 @@ int pdu2text(char *pdu, char *text, int *text_length, int *expected_length,
   int octetcounter;
   int skip_characters = 0;
   char c;
-  char binary = 0;
+  char binary;
   int i;
   int result;
 
@@ -899,7 +807,7 @@ int pdu2binary(char* pdu, char* binary, int *data_length, int *expected_length,
 int explain_toa(char *dest, char *octet_char, int octet_int)
 {
   int result;
-  char *p = "reserved";
+  char *p;
 
   if (octet_char)
     result = octet2bin_check(octet_char);
@@ -917,7 +825,7 @@ int explain_toa(char *dest, char *octet_char, int octet_int)
       case 4: p = "subsciber"; break;
       case 5: p = "alphanumeric"; break;
       case 6: p = "abbreviated"; break;
-      //case 7: p = "reserved"; break;
+      case 7: p = "reserved"; break;
     }
 
     if (octet_char)
@@ -934,7 +842,7 @@ int explain_toa(char *dest, char *octet_char, int octet_int)
       case 8: p = "national"; break;
       case 9: p = "private"; break;
       case 10: p = "ERMES"; break;
-      //default: p = "reserved"; break;
+      default: p = "reserved"; break;
     }
     sprintf(strchr(dest, 0), ", %s", p);
   }
@@ -949,15 +857,13 @@ int explain_toa(char *dest, char *octet_char, int octet_int)
 // sendr Sender
 // date and time Date/Time-stamp
 // message the message text or binary data
-// bin_udh: 1 if udh is taken from the PDU with binary messages too
 // returns length of message
 int split_type_0(char *full_pdu, char* Src_Pointer, int* alphabet, char* sendr, char* date, char* time,
                  char* message, int *message_length, int *expected_length, int with_udh, char* udh_data,
-                 char *udh_type, char *from_toa, int *replace, char **err_str, char *warning_headers,
-                 int *flash, int bin_udh)
+                 char *udh_type, char *from_toa, int *replace, char **err_str, char *warning_headers, int *flash)
 {
   int Length;
-  int padding = 0;
+  int padding;
   char tmpsender[100];
   int result = 0;
   int i;
@@ -973,13 +879,9 @@ int split_type_0(char *full_pdu, char* Src_Pointer, int* alphabet, char* sendr,
   else
   {
     Length = octet2bin_check(Src_Pointer);
-    // 3.1.5: Sender address length can be zero. There is still address type octet (80).
-    if (Length < 0 || Length > MAX_ADDRESS_LENGTH)
+    if (Length < 1 || Length > MAX_ADDRESS_LENGTH)
       pdu_error(err_str, 0, Src_Pointer -full_pdu, 2, "Invalid sender address length: \"%.2s\"", Src_Pointer);
     else
-    if (Length == 0)
-      Src_Pointer += 4;
-    else
     {
       padding=Length%2;
       Src_Pointer+=2;
@@ -993,7 +895,7 @@ int split_type_0(char *full_pdu, char* Src_Pointer, int* alphabet, char* sendr,
         Src_Pointer += 2;
         if ((i & 112) == 80)
         {  // Sender is alphanumeric
-          if (strlen(Src_Pointer) < (size_t)(Length +padding))
+          if (strlen(Src_Pointer) < Length +padding)
             pdu_error(err_str, 0, Src_Pointer -full_pdu, Length +padding,
                       "While trying to read sender address (alphanumeric, length %i): %s",
                       Length +padding, err_too_short);
@@ -1007,7 +909,7 @@ int split_type_0(char *full_pdu, char* Src_Pointer, int* alphabet, char* sendr,
         }
         else
         {  // sender is numeric
-          if (strlen(Src_Pointer) < (size_t)(Length +padding))
+          if (strlen(Src_Pointer) < Length +padding)
             pdu_error(err_str, 0, Src_Pointer -full_pdu, Length +padding,
                       "While trying to read sender address (numeric, length %i): %s",
                       Length +padding, err_too_short);
@@ -1038,7 +940,7 @@ int split_type_0(char *full_pdu, char* Src_Pointer, int* alphabet, char* sendr,
               {
                 // Not a fatal error (?)
                 //pdu_error(err_str, 0, Src_Pointer -full_pdu, Length +padding, "Invalid character(s) in sender address: \"%s\"", sendr);
-                // *sendr = 0;
+                //*sendr = 0;
                 add_warning(warning_headers, "Invalid character(s) in sender address.");
                 break;
               }
@@ -1097,7 +999,7 @@ int split_type_0(char *full_pdu, char* Src_Pointer, int* alphabet, char* sendr,
               {
                 // Not a fatal error (?)
                 //pdu_error(err_str, 0, Src_Pointer -full_pdu, 6, "Invalid value(s) in date of Service Centre Time Stamp: \"%s\"", date);
-                // *date = 0;
+                //*date = 0;
                 add_warning(warning_headers, "Invalid values(s) in date of Service Centre Time Stamp.");
               }
 
@@ -1112,7 +1014,7 @@ int split_type_0(char *full_pdu, char* Src_Pointer, int* alphabet, char* sendr,
               {
                 // Not a fatal error (?)
                 //pdu_error(err_str, 0, Src_Pointer -full_pdu, 6, "Invalid value(s) in time of Service Centre Time Stamp: \"%s\"", time);
-                // *time = 0;
+                //*time = 0;
                 add_warning(warning_headers, "Invalid values(s) in time of Service Centre Time Stamp.");
               }
 
@@ -1147,10 +1049,8 @@ int split_type_0(char *full_pdu, char* Src_Pointer, int* alphabet, char* sendr,
       {
         // With binary messages udh is NOT taken from the PDU.
         i = with_udh;
-        // 3.1.5: it should work now:
-        if (bin_udh == 0)
-          if (*alphabet == 1)
-            i = 0;
+        if (*alphabet == 1)
+          i = 0;
         if ((result = pdu2binary(Src_Pointer, message, message_length, expected_length, i, udh_data, udh_type, &errorpos)) < 0)
           pdu_error(err_str, 0, Src_Pointer -full_pdu +errorpos, 0, "While reading TP-UD (%s): %s",
                     (*alphabet == 1)? "binary" : "UCS2 text",
@@ -1216,7 +1116,7 @@ int split_type_2(char *full_pdu, char* Src_Pointer,char* sendr, char* date,char*
           Src_Pointer += 2;
           if ((i & 112) == 80)
           {  // Sender is alphanumeric
-            if (strlen(Src_Pointer) < (size_t)(Length +padding))
+            if (strlen(Src_Pointer) < Length +padding)
               pdu_error(err_str, 0, Src_Pointer -full_pdu, Length +padding,
                         "While trying to read recipient address (alphanumeric, length %i): %s",
                         Length +padding, err_too_short);
@@ -1230,7 +1130,7 @@ int split_type_2(char *full_pdu, char* Src_Pointer,char* sendr, char* date,char*
           }
           else
           {  // sender is numeric
-            if (strlen(Src_Pointer) < (size_t)(Length +padding))
+            if (strlen(Src_Pointer) < Length +padding)
               pdu_error(err_str, 0, Src_Pointer -full_pdu, Length +padding,
                         "While trying to read recipient address (numeric, length %i): %s",
                         Length +padding, err_too_short);
@@ -1261,7 +1161,7 @@ int split_type_2(char *full_pdu, char* Src_Pointer,char* sendr, char* date,char*
                 {
                   // Not a fatal error (?)
                   //pdu_error(err_str, 0, Src_Pointer -full_pdu, Length +padding, "Invalid character(s) in recipient address: \"%s\"", sendr);
-                  // *sendr = 0;
+                  //*sendr = 0;
                   add_warning(warning_headers, "Invalid character(s) in recipient address.");
                   break;
                 }
@@ -1286,7 +1186,7 @@ int split_type_2(char *full_pdu, char* Src_Pointer,char* sendr, char* date,char*
               {
                 // Not a fatal error (?)
                 //pdu_error(err_str, 0, Src_Pointer -full_pdu, 6, "Invalid value(s) in date of SMSC Timestamp: \"%s\"", date);
-                // *date = 0;
+                //*date = 0;
                 add_warning(warning_headers, "Invalid value(s) in date of SMSC Timestamp.");
               }
 
@@ -1301,7 +1201,7 @@ int split_type_2(char *full_pdu, char* Src_Pointer,char* sendr, char* date,char*
               {
                 // Not a fatal error (?)
                 //pdu_error(err_str, 0, Src_Pointer -full_pdu, 6, "Invalid value(s) in time of SMSC Timestamp: \"%s\"", time);
-                // *time = 0;
+                //*time = 0;
                 add_warning(warning_headers, "Invalid value(s) in time of SMSC Timestamp.");
               }
 
@@ -1422,8 +1322,7 @@ int split_type_2(char *full_pdu, char* Src_Pointer,char* sendr, char* date,char*
 // Returns the length of the message 
 int splitpdu(char *pdu, char *mode, int *alphabet, char *sendr, char *date, char *time, char *message,
              char *smsc, int *with_udh, char *a_udh_data, char *a_udh_type, int *is_statusreport,
-             int *is_unsupported_pdu, char *from_toa, int *report, int *replace, char *warning_headers,
-             int *flash, int bin_udh)
+             int *is_unsupported_pdu, char *from_toa, int *report, int *replace, char *warning_headers, int *flash)
 {
   int Length;
   int Type;
@@ -1447,7 +1346,7 @@ int splitpdu(char *pdu, char *mode, int *alphabet, char *sendr, char *date, char
   // Patch for Wavecom SR memory reading:
   if (strncmp(pdu, "000000FF00", 10) == 0)
   {
-    memmove(pdu, pdu +8, strlen(pdu +8) +1);
+    strcpy(pdu, pdu +8);
     while (strlen(pdu) < 52)
       strcat(pdu, "00");
   }
@@ -1512,7 +1411,7 @@ int splitpdu(char *pdu, char *mode, int *alphabet, char *sendr, char *date, char
             {
               Length = Length *2 -2;
               // No padding because the given value is number of octets.
-              if (strlen(Pointer) < (size_t)(Length +4))
+              if (strlen(Pointer) < Length +4)
                 pdu_error(&err_str, 0, Pointer -pdu, Length +4, "While trying to read sender SMSC address (length %i): %s",
                           Length, err_too_short);
               else
@@ -1552,7 +1451,7 @@ int splitpdu(char *pdu, char *mode, int *alphabet, char *sendr, char *date, char
                       {
                         // Not a fatal error (?)
                         //pdu_error(&err_str, 0, Pointer -pdu, Length, "Invalid character(s) in numeric SMSC address: \"%s\"", smsc);
-                        // *smsc = 0;
+                        //*smsc = 0;
                         add_warning(warning_headers, "Invalid character(s) in numeric SMSC address");
                         break;
                       }
@@ -1591,7 +1490,7 @@ int splitpdu(char *pdu, char *mode, int *alphabet, char *sendr, char *date, char
             {
               Pointer += 2;
               result = split_type_0(pdu, Pointer, alphabet, sendr, date, time, message, &message_length, &expected_length,
-                                    *with_udh, udh_data, udh_type, from_toa, replace, &err_str, warning_headers, flash, bin_udh);
+                                    *with_udh, udh_data, udh_type, from_toa, replace, &err_str, warning_headers, flash);
 
               if (err_str && *udh_type)
                 pdu_error(&err_str, "", -1, 0, "Message has Udh_type: %s", udh_type);
@@ -1610,12 +1509,8 @@ int splitpdu(char *pdu, char *mode, int *alphabet, char *sendr, char *date, char
                 else
                 {
                   memcpy(ascii, message, message_length);
-#ifndef USE_ICONV
                   ascii[message_length] = 0;
                   i = decode_ucs2(ascii, message_length);
-#else
-                  i = (int)iconv_ucs2utf(ascii, message_length, sizeof(ascii));
-#endif
                   expected_length /= 2;
                 }
 
@@ -1697,143 +1592,3 @@ int splitpdu(char *pdu, char *mode, int *alphabet, char *sendr, char *date, char
 
   return result;
 }
-
-int get_pdu_details(char *dest, size_t size_dest, char *pdu, int mnumber)
-{
-  int result = 0;
-  int udlen;
-  int alphabet;
-  char sender[100];
-  char date[9];
-  char time[9];
-  char ascii[MAXTEXT];
-  char smsc[31];
-  int with_udh;
-  char udh_data[SIZE_UDH_DATA];
-  char udh_type[SIZE_UDH_TYPE];
-  int is_statusreport;
-  int is_unsupported_pdu;
-  char from_toa[51];
-  int report;
-  int replace;
-  char warning_headers[SIZE_WARNING_HEADERS];
-  int flash;
-  int bin_udh = 1;
-  int m_id = 999; // real id for concatenated messages only, others use this.
-  size_t length_sender = 32;
-  int p_count = 1;
-  int p_number = 1;
-  char buffer[100]; // 3.1.6: increased size, was too small (51).
-  int i;
-  char sort_ch;
-  char *p;
-
-  udlen = splitpdu(pdu, DEVICE.mode, &alphabet, sender, date, time, ascii, smsc, &with_udh, udh_data, udh_type,
-                   &is_statusreport, &is_unsupported_pdu, from_toa, &report, &replace, warning_headers, &flash, bin_udh);
-
-  if (is_unsupported_pdu)
-  {
-    writelogfile(LOG_ERR, 1, "Message %i, unsupported PDU.", mnumber);
-    result = 1;
-  }
-  else
-  {
-    if (with_udh)
-    {
-      if (get_remove_concatenation(udh_data, &m_id, &p_count, &p_number) < 0)
-      {
-        writelogfile(LOG_ERR, 1, "Message %i, error while checking UDH_DATA.", mnumber);
-        result = 2;
-      }
-    }
-
-    if (!result)
-    {
-      if (strlen(sender) > length_sender)
-      {
-        writelogfile(LOG_ERR, 1, "Message %i, too long sender field.", mnumber);
-        result = 3;
-      }    
-
-      while (strlen(sender) < length_sender)
-        strcat(sender, " ");
-
-      if (DEVICE.priviledged_numbers[0])
-        p = DEVICE.priviledged_numbers;
-      else
-      if (priviledged_numbers[0])
-        p = priviledged_numbers;
-      else
-        p = 0;
-
-      sort_ch = 'Z';
-      if (p)
-      {
-        i = 0;
-        while (*p)
-        {
-          if (strncmp(sender, p, strlen(p)) == 0)
-          {
-            sort_ch = 'A' +i;
-            break;
-          }
-          i++;
-          p = strchr(p, 0) +1;
-        }
-      }
-/*
-001 A 358401234567____________________111 001/001 r 00-00-00 00-00-00n
-mnumber
-    sort_ch
-      sender
-                                      m_id
-                                          p_number
-                                              p_count
-                                                  incoming / report
-                                                    date
-                                                             time
-
-      snprintf(buffer, sizeof(buffer), "%.03i %c %s%.03i %.03i/%.03i %c %-8.8s %-8.8s\n",
-               mnumber, sort_ch, sender, m_id, p_number, p_count, (is_statusreport) ? 'r' : 'i', date, time);
-
-3.1.7:
-001 A 00-00-00 00-00-00 358401234567____________________111 001/001 rn
-mnumber
-    sort_ch
-      date
-               time
-                        sender
-                                                        m_id
-                                                            p_number
-                                                                p_count
-                                                                    incoming / report
-*/
-      snprintf(buffer, sizeof(buffer), "%.03i %c %-8.8s %-8.8s %s%.03i %.03i/%.03i %c\n", mnumber, sort_ch, date, time, sender, m_id, p_number, p_count, (is_statusreport) ? 'r' : 'i');
-
-      if (strlen(dest) +strlen(buffer) < size_dest)
-        strcat(dest, buffer);
-      else
-      {
-        writelogfile(LOG_ERR, 1, "Message %i, not enough storage space.", mnumber);
-        result = 4;
-      }
-    }
-  }
-
-  return result;
-}
-
-int sort_pdu_helper(const void *a, const void *b)
-{
-  //return(strncmp((char *)a +4, (char *)b +4, 45));
-  return (strncmp((char *) a + 4, (char *) b + 4, 63));
-}
-
-void sort_pdu_details(char *dest)
-{
-  int count;
-
-  count = strlen(dest) / LENGTH_PDU_DETAIL_REC;
-  if (count > 1)
-    qsort((void *)dest, count, LENGTH_PDU_DETAIL_REC, sort_pdu_helper);
-}
